/**
 * Represents a double-valued filter parameter.
 */
public class DoubleFilterParam extends FilterParam {
	private final String name;
	private final double min;
	private final double max;
	private double value;
	
	// ### INIT ###
	
	/**
	 * @param name	the name of this parameter, as it will be displayed in the GUI
	 * @param min	the minimum value of this parameter (inclusive),
	 * 				or <tt>Double.MIN_VALUE</tt> to indicate an unbounded minimum
	 * @param max	the maximum value of this parameter (inclusive),
	 * 				or <tt>Double.MAX_VALUE</tt> to indicate an unbounded maximum
	 */
	public DoubleFilterParam(String name, double min, double max) {
		this(name, min, max, min);
	}
	
	/**
	 * @param name	the name of this parameter, as it will be displayed in the GUI
	 * @param min	the minimum value of this parameter (inclusive),
	 * 				or <tt>Float.MIN_VALUE</tt> to indicate an unbounded minimum
	 * @param max	the maximum value of this parameter (inclusive),
	 * 				or <tt>Float.MAX_VALUE</tt> to indicate an unbounded maximum
	 * @param value	the initial value of this parameter
	 */
	public DoubleFilterParam(String name, double min, double max, double value) {
		this.name = name;
		this.min = min;
		this.max = max;
		this.setValue(value);
	}
	
	// ### ACCESSORS ###
	
	public String getName() {
		return this.name;
	}
	
	public double getMin() {
		return this.min;
	}
	
	public double getMax() {
		return this.max;
	}
	
	public double getValue() {
		return this.value;
	}
	
	public void setValue(double value) {
		if (value < this.min)
			throw new IllegalArgumentException(
				"value out of range (value < min): "+value+" < "+min);
		if (value > this.max)
			throw new IllegalArgumentException(
				"value out of range (value > max): "+value+" > "+max);
		this.value = value;
	}
}