import java.awt.image.BufferedImage;

public class PixelBufferToBufferedImageFilterAsBufferedImageFilter2 implements BufferedImageFilter2 {
	private PixelBufferToBufferedImageFilter bufImgFilter;
	private int[] inPixelBuffer;
	
	public PixelBufferToBufferedImageFilterAsBufferedImageFilter2(PixelBufferToBufferedImageFilter bufImgFilter) {
		this.bufImgFilter = bufImgFilter;
		this.inPixelBuffer = null;
	}
	
	public void filter(BufferedImage inImg, BufferedImage outImg) {
		int width = inImg.getWidth();
		int height = inImg.getHeight();
		int numPixels = width*height;
		
		// Ensure the size of the pixel buffer matches the number of pixels in the image
		if ((inPixelBuffer == null) || (inPixelBuffer.length != numPixels)) {
			inPixelBuffer = new int[numPixels];
		}
		
		// Read the image's pixels into the pixel buffer
		inImg.getRGB(0, 0, width, height, inPixelBuffer, 0, width);
		
		// Filter the contents of the pixel buffer, storing the result in the output image
		bufImgFilter.filter(width, height, inPixelBuffer, inImg, outImg);
	}
	
	public String toString() {
		return bufImgFilter.toString();
	}
}